@@ -7,10 +7,7 @@ from SyscallAnalysis.libsyscall.analyzer.syscall_trace_constructor import Syscal
 
 @click.command()
 @click.argument("input_file", type=click.File())
-@click.option('--echo', is_flag=True, help='echo the decoded scall trace.')
-# @click.option("-c", '--cwd', "cwd_path", type=click.Path(exists=True),
-#               help='the CWD used for evaluate out-of-tree file access.')
-def main(input_file, echo):
+def main(input_file):
     cwd_path = os.path.abspath(os.path.dirname(input_file.name))
 
     trace_cntr = SyscallTraceConstructor(cwd_path)
